<?php

return [
    'Names' => [
        'af' => 'अफ्रिकान्स',
        'af_NA' => 'अफ्रिकान्स (नामिबिया)',
        'af_ZA' => 'अफ्रिकान्स (दक्षिण आफ्रिका)',
        'ak' => 'अकान',
        'ak_GH' => 'अकान (घाना)',
        'am' => 'अम्हारिक',
        'am_ET' => 'अम्हारिक (इथिओपिया)',
        'ar' => 'अरबी',
        'ar_001' => 'अरबी (विश्व)',
        'ar_AE' => 'अरबी (संयुक्त अरब अमीरात)',
        'ar_BH' => 'अरबी (बहारीन)',
        'ar_DJ' => 'अरबी (जिबौटी)',
        'ar_DZ' => 'अरबी (अल्जीरिया)',
        'ar_EG' => 'अरबी (इजिप्त)',
        'ar_EH' => 'अरबी (पश्चिम सहारा)',
        'ar_ER' => 'अरबी (एरिट्रिया)',
        'ar_IL' => 'अरबी (इस्त्राइल)',
        'ar_IQ' => 'अरबी (इराक)',
        'ar_JO' => 'अरबी (जॉर्डन)',
        'ar_KM' => 'अरबी (कोमोरोज)',
        'ar_KW' => 'अरबी (कुवेत)',
        'ar_LB' => 'अरबी (लेबनॉन)',
        'ar_LY' => 'अरबी (लिबिया)',
        'ar_MA' => 'अरबी (मोरोक्को)',
        'ar_MR' => 'अरबी (मॉरिटानिया)',
        'ar_OM' => 'अरबी (ओमान)',
        'ar_PS' => 'अरबी (पॅलेस्टिनियन प्रदेश)',
        'ar_QA' => 'अरबी (कतार)',
        'ar_SA' => 'अरबी (सौदी अरब)',
        'ar_SD' => 'अरबी (सुदान)',
        'ar_SO' => 'अरबी (सोमालिया)',
        'ar_SS' => 'अरबी (दक्षिण सुदान)',
        'ar_SY' => 'अरबी (सीरिया)',
        'ar_TD' => 'अरबी (चाड)',
        'ar_TN' => 'अरबी (ट्यूनिशिया)',
        'ar_YE' => 'अरबी (येमेन)',
        'as' => 'आसामी',
        'as_IN' => 'आसामी (भारत)',
        'az' => 'अझरबैजानी',
        'az_AZ' => 'अझरबैजानी (अझरबैजान)',
        'az_Cyrl' => 'अझरबैजानी (सीरिलिक)',
        'az_Cyrl_AZ' => 'अझरबैजानी (सीरिलिक, अझरबैजान)',
        'az_Latn' => 'अझरबैजानी (लॅटिन)',
        'az_Latn_AZ' => 'अझरबैजानी (लॅटिन, अझरबैजान)',
        'be' => 'बेलारुशियन',
        'be_BY' => 'बेलारुशियन (बेलारूस)',
        'bg' => 'बल्गेरियन',
        'bg_BG' => 'बल्गेरियन (बल्गेरिया)',
        'bm' => 'बाम्बारा',
        'bm_ML' => 'बाम्बारा (माली)',
        'bn' => 'बंगाली',
        'bn_BD' => 'बंगाली (बांगलादेश)',
        'bn_IN' => 'बंगाली (भारत)',
        'bo' => 'तिबेटी',
        'bo_CN' => 'तिबेटी (चीन)',
        'bo_IN' => 'तिबेटी (भारत)',
        'br' => 'ब्रेतॉन',
        'br_FR' => 'ब्रेतॉन (फ्रान्स)',
        'bs' => 'बोस्नियन',
        'bs_BA' => 'बोस्नियन (बोस्निया अणि हर्जेगोविना)',
        'bs_Cyrl' => 'बोस्नियन (सीरिलिक)',
        'bs_Cyrl_BA' => 'बोस्नियन (सीरिलिक, बोस्निया अणि हर्जेगोविना)',
        'bs_Latn' => 'बोस्नियन (लॅटिन)',
        'bs_Latn_BA' => 'बोस्नियन (लॅटिन, बोस्निया अणि हर्जेगोविना)',
        'ca' => 'कातालान',
        'ca_AD' => 'कातालान (अँडोरा)',
        'ca_ES' => 'कातालान (स्पेन)',
        'ca_FR' => 'कातालान (फ्रान्स)',
        'ca_IT' => 'कातालान (इटली)',
        'ce' => 'चेचेन',
        'ce_RU' => 'चेचेन (रशिया)',
        'cs' => 'झेक',
        'cs_CZ' => 'झेक (झेकिया)',
        'cv' => 'चूवाश',
        'cv_RU' => 'चूवाश (रशिया)',
        'cy' => 'वेल्श',
        'cy_GB' => 'वेल्श (युनायटेड किंगडम)',
        'da' => 'डॅनिश',
        'da_DK' => 'डॅनिश (डेन्मार्क)',
        'da_GL' => 'डॅनिश (ग्रीनलंड)',
        'de' => 'जर्मन',
        'de_AT' => 'जर्मन (ऑस्ट्रिया)',
        'de_BE' => 'जर्मन (बेल्जियम)',
        'de_CH' => 'जर्मन (स्वित्झर्लंड)',
        'de_DE' => 'जर्मन (जर्मनी)',
        'de_IT' => 'जर्मन (इटली)',
        'de_LI' => 'जर्मन (लिक्टेनस्टाइन)',
        'de_LU' => 'जर्मन (लक्झेंबर्ग)',
        'dz' => 'झोंगखा',
        'dz_BT' => 'झोंगखा (भूतान)',
        'ee' => 'एवे',
        'ee_GH' => 'एवे (घाना)',
        'ee_TG' => 'एवे (टोगो)',
        'el' => 'ग्रीक',
        'el_CY' => 'ग्रीक (सायप्रस)',
        'el_GR' => 'ग्रीक (ग्रीस)',
        'en' => 'इंग्रजी',
        'en_001' => 'इंग्रजी (विश्व)',
        'en_150' => 'इंग्रजी (युरोप)',
        'en_AE' => 'इंग्रजी (संयुक्त अरब अमीरात)',
        'en_AG' => 'इंग्रजी (अँटिग्वा आणि बर्बुडा)',
        'en_AI' => 'इंग्रजी (अँग्विला)',
        'en_AS' => 'इंग्रजी (अमेरिकन सामोआ)',
        'en_AT' => 'इंग्रजी (ऑस्ट्रिया)',
        'en_AU' => 'इंग्रजी (ऑस्ट्रेलिया)',
        'en_BB' => 'इंग्रजी (बार्बाडोस)',
        'en_BE' => 'इंग्रजी (बेल्जियम)',
        'en_BI' => 'इंग्रजी (बुरुंडी)',
        'en_BM' => 'इंग्रजी (बर्मुडा)',
        'en_BS' => 'इंग्रजी (बहामाज)',
        'en_BW' => 'इंग्रजी (बोट्सवाना)',
        'en_BZ' => 'इंग्रजी (बेलिझे)',
        'en_CA' => 'इंग्रजी (कॅनडा)',
        'en_CC' => 'इंग्रजी (कोकोस [कीलिंग] बेटे)',
        'en_CH' => 'इंग्रजी (स्वित्झर्लंड)',
        'en_CK' => 'इंग्रजी (कुक बेटे)',
        'en_CM' => 'इंग्रजी (कॅमेरून)',
        'en_CX' => 'इंग्रजी (ख्रिसमस बेट)',
        'en_CY' => 'इंग्रजी (सायप्रस)',
        'en_DE' => 'इंग्रजी (जर्मनी)',
        'en_DK' => 'इंग्रजी (डेन्मार्क)',
        'en_DM' => 'इंग्रजी (डोमिनिका)',
        'en_ER' => 'इंग्रजी (एरिट्रिया)',
        'en_FI' => 'इंग्रजी (फिनलंड)',
        'en_FJ' => 'इंग्रजी (फिजी)',
        'en_FK' => 'इंग्रजी (फॉकलंड बेटे)',
        'en_FM' => 'इंग्रजी (मायक्रोनेशिया)',
        'en_GB' => 'इंग्रजी (युनायटेड किंगडम)',
        'en_GD' => 'इंग्रजी (ग्रेनेडा)',
        'en_GG' => 'इंग्रजी (ग्वेर्नसे)',
        'en_GH' => 'इंग्रजी (घाना)',
        'en_GI' => 'इंग्रजी (जिब्राल्टर)',
        'en_GM' => 'इंग्रजी (गाम्बिया)',
        'en_GU' => 'इंग्रजी (गुआम)',
        'en_GY' => 'इंग्रजी (गयाना)',
        'en_HK' => 'इंग्रजी (हाँगकाँग एसएआर चीन)',
        'en_IE' => 'इंग्रजी (आयर्लंड)',
        'en_IL' => 'इंग्रजी (इस्त्राइल)',
        'en_IM' => 'इंग्रजी (आयल ऑफ मॅन)',
        'en_IN' => 'इंग्रजी (भारत)',
        'en_IO' => 'इंग्रजी (ब्रिटिश हिंद महासागर प्रदेश)',
        'en_JE' => 'इंग्रजी (जर्सी)',
        'en_JM' => 'इंग्रजी (जमैका)',
        'en_KE' => 'इंग्रजी (केनिया)',
        'en_KI' => 'इंग्रजी (किरीबाटी)',
        'en_KN' => 'इंग्रजी (सेंट किट्स आणि नेव्हिस)',
        'en_KY' => 'इंग्रजी (केमन बेटे)',
        'en_LC' => 'इंग्रजी (सेंट ल्यूसिया)',
        'en_LR' => 'इंग्रजी (लायबेरिया)',
        'en_LS' => 'इंग्रजी (लेसोथो)',
        'en_MG' => 'इंग्रजी (मादागास्कर)',
        'en_MH' => 'इंग्रजी (मार्शल बेटे)',
        'en_MO' => 'इंग्रजी (मकाओ एसएआर चीन)',
        'en_MP' => 'इंग्रजी (उत्तरी मारियाना बेटे)',
        'en_MS' => 'इंग्रजी (मॉन्ट्सेराट)',
        'en_MT' => 'इंग्रजी (माल्टा)',
        'en_MU' => 'इंग्रजी (मॉरिशस)',
        'en_MV' => 'इंग्रजी (मालदीव)',
        'en_MW' => 'इंग्रजी (मलावी)',
        'en_MY' => 'इंग्रजी (मलेशिया)',
        'en_NA' => 'इंग्रजी (नामिबिया)',
        'en_NF' => 'इंग्रजी (नॉरफॉक बेट)',
        'en_NG' => 'इंग्रजी (नायजेरिया)',
        'en_NL' => 'इंग्रजी (नेदरलँड)',
        'en_NR' => 'इंग्रजी (नाउरू)',
        'en_NU' => 'इंग्रजी (नीयू)',
        'en_NZ' => 'इंग्रजी (न्यूझीलंड)',
        'en_PG' => 'इंग्रजी (पापुआ न्यू गिनी)',
        'en_PH' => 'इंग्रजी (फिलिपिन्स)',
        'en_PK' => 'इंग्रजी (पाकिस्तान)',
        'en_PN' => 'इंग्रजी (पिटकैर्न बेटे)',
        'en_PR' => 'इंग्रजी (प्युएर्तो रिको)',
        'en_PW' => 'इंग्रजी (पलाऊ)',
        'en_RW' => 'इंग्रजी (रवांडा)',
        'en_SB' => 'इंग्रजी (सोलोमन बेटे)',
        'en_SC' => 'इंग्रजी (सेशेल्स)',
        'en_SD' => 'इंग्रजी (सुदान)',
        'en_SE' => 'इंग्रजी (स्वीडन)',
        'en_SG' => 'इंग्रजी (सिंगापूर)',
        'en_SH' => 'इंग्रजी (सेंट हेलेना)',
        'en_SI' => 'इंग्रजी (स्लोव्हेनिया)',
        'en_SL' => 'इंग्रजी (सिएरा लिओन)',
        'en_SS' => 'इंग्रजी (दक्षिण सुदान)',
        'en_SX' => 'इंग्रजी (सिंट मार्टेन)',
        'en_SZ' => 'इंग्रजी (इस्वातिनी)',
        'en_TC' => 'इंग्रजी (टर्क्स आणि कैकोस बेटे)',
        'en_TK' => 'इंग्रजी (तोकेलाउ)',
        'en_TO' => 'इंग्रजी (टोंगा)',
        'en_TT' => 'इंग्रजी (त्रिनिदाद आणि टोबॅगो)',
        'en_TV' => 'इंग्रजी (टुवालु)',
        'en_TZ' => 'इंग्रजी (टांझानिया)',
        'en_UG' => 'इंग्रजी (युगांडा)',
        'en_UM' => 'इंग्रजी (यू.एस. आउटलाइंग बेटे)',
        'en_US' => 'इंग्रजी (युनायटेड स्टेट्स)',
        'en_VC' => 'इंग्रजी (सेंट व्हिन्सेंट आणि ग्रेनडाइन्स)',
        'en_VG' => 'इंग्रजी (ब्रिटिश व्हर्जिन बेटे)',
        'en_VI' => 'इंग्रजी (यू.एस. व्हर्जिन बेटे)',
        'en_VU' => 'इंग्रजी (वानुआतु)',
        'en_WS' => 'इंग्रजी (सामोआ)',
        'en_ZA' => 'इंग्रजी (दक्षिण आफ्रिका)',
        'en_ZM' => 'इंग्रजी (झाम्बिया)',
        'en_ZW' => 'इंग्रजी (झिम्बाब्वे)',
        'eo' => 'एस्परान्टो',
        'eo_001' => 'एस्परान्टो (विश्व)',
        'es' => 'स्पॅनिश',
        'es_419' => 'स्पॅनिश (लॅटिन अमेरिका)',
        'es_AR' => 'स्पॅनिश (अर्जेंटिना)',
        'es_BO' => 'स्पॅनिश (बोलिव्हिया)',
        'es_BR' => 'स्पॅनिश (ब्राझिल)',
        'es_BZ' => 'स्पॅनिश (बेलिझे)',
        'es_CL' => 'स्पॅनिश (चिली)',
        'es_CO' => 'स्पॅनिश (कोलम्बिया)',
        'es_CR' => 'स्पॅनिश (कोस्टा रिका)',
        'es_CU' => 'स्पॅनिश (क्यूबा)',
        'es_DO' => 'स्पॅनिश (डोमिनिकन प्रजासत्ताक)',
        'es_EC' => 'स्पॅनिश (इक्वाडोर)',
        'es_ES' => 'स्पॅनिश (स्पेन)',
        'es_GQ' => 'स्पॅनिश (इक्वेटोरियल गिनी)',
        'es_GT' => 'स्पॅनिश (ग्वाटेमाला)',
        'es_HN' => 'स्पॅनिश (होंडुरास)',
        'es_MX' => 'स्पॅनिश (मेक्सिको)',
        'es_NI' => 'स्पॅनिश (निकाराग्वा)',
        'es_PA' => 'स्पॅनिश (पनामा)',
        'es_PE' => 'स्पॅनिश (पेरू)',
        'es_PH' => 'स्पॅनिश (फिलिपिन्स)',
        'es_PR' => 'स्पॅनिश (प्युएर्तो रिको)',
        'es_PY' => 'स्पॅनिश (पराग्वे)',
        'es_SV' => 'स्पॅनिश (अल साल्वाडोर)',
        'es_US' => 'स्पॅनिश (युनायटेड स्टेट्स)',
        'es_UY' => 'स्पॅनिश (उरुग्वे)',
        'es_VE' => 'स्पॅनिश (व्हेनेझुएला)',
        'et' => 'इस्टोनियन',
        'et_EE' => 'इस्टोनियन (एस्टोनिया)',
        'eu' => 'बास्क',
        'eu_ES' => 'बास्क (स्पेन)',
        'fa' => 'फारसी',
        'fa_AF' => 'फारसी (अफगाणिस्तान)',
        'fa_IR' => 'फारसी (इराण)',
        'ff' => 'फुलाह',
        'ff_Adlm' => 'फुलाह (अदलम)',
        'ff_Adlm_BF' => 'फुलाह (अदलम, बुर्किना फासो)',
        'ff_Adlm_CM' => 'फुलाह (अदलम, कॅमेरून)',
        'ff_Adlm_GH' => 'फुलाह (अदलम, घाना)',
        'ff_Adlm_GM' => 'फुलाह (अदलम, गाम्बिया)',
        'ff_Adlm_GN' => 'फुलाह (अदलम, गिनी)',
        'ff_Adlm_GW' => 'फुलाह (अदलम, गिनी-बिसाउ)',
        'ff_Adlm_LR' => 'फुलाह (अदलम, लायबेरिया)',
        'ff_Adlm_MR' => 'फुलाह (अदलम, मॉरिटानिया)',
        'ff_Adlm_NE' => 'फुलाह (अदलम, नाइजर)',
        'ff_Adlm_NG' => 'फुलाह (अदलम, नायजेरिया)',
        'ff_Adlm_SL' => 'फुलाह (अदलम, सिएरा लिओन)',
        'ff_Adlm_SN' => 'फुलाह (अदलम, सेनेगल)',
        'ff_CM' => 'फुलाह (कॅमेरून)',
        'ff_GN' => 'फुलाह (गिनी)',
        'ff_Latn' => 'फुलाह (लॅटिन)',
        'ff_Latn_BF' => 'फुलाह (लॅटिन, बुर्किना फासो)',
        'ff_Latn_CM' => 'फुलाह (लॅटिन, कॅमेरून)',
        'ff_Latn_GH' => 'फुलाह (लॅटिन, घाना)',
        'ff_Latn_GM' => 'फुलाह (लॅटिन, गाम्बिया)',
        'ff_Latn_GN' => 'फुलाह (लॅटिन, गिनी)',
        'ff_Latn_GW' => 'फुलाह (लॅटिन, गिनी-बिसाउ)',
        'ff_Latn_LR' => 'फुलाह (लॅटिन, लायबेरिया)',
        'ff_Latn_MR' => 'फुलाह (लॅटिन, मॉरिटानिया)',
        'ff_Latn_NE' => 'फुलाह (लॅटिन, नाइजर)',
        'ff_Latn_NG' => 'फुलाह (लॅटिन, नायजेरिया)',
        'ff_Latn_SL' => 'फुलाह (लॅटिन, सिएरा लिओन)',
        'ff_Latn_SN' => 'फुलाह (लॅटिन, सेनेगल)',
        'ff_MR' => 'फुलाह (मॉरिटानिया)',
        'ff_SN' => 'फुलाह (सेनेगल)',
        'fi' => 'फिन्निश',
        'fi_FI' => 'फिन्निश (फिनलंड)',
        'fo' => 'फरोइज',
        'fo_DK' => 'फरोइज (डेन्मार्क)',
        'fo_FO' => 'फरोइज (फेरो बेटे)',
        'fr' => 'फ्रेंच',
        'fr_BE' => 'फ्रेंच (बेल्जियम)',
        'fr_BF' => 'फ्रेंच (बुर्किना फासो)',
        'fr_BI' => 'फ्रेंच (बुरुंडी)',
        'fr_BJ' => 'फ्रेंच (बेनिन)',
        'fr_BL' => 'फ्रेंच (सेंट बार्थेलेमी)',
        'fr_CA' => 'फ्रेंच (कॅनडा)',
        'fr_CD' => 'फ्रेंच (काँगो - किंशासा)',
        'fr_CF' => 'फ्रेंच (केंद्रीय अफ्रिकी प्रजासत्ताक)',
        'fr_CG' => 'फ्रेंच (काँगो - ब्राझाविले)',
        'fr_CH' => 'फ्रेंच (स्वित्झर्लंड)',
        'fr_CI' => 'फ्रेंच (कोत द’ईवोआर)',
        'fr_CM' => 'फ्रेंच (कॅमेरून)',
        'fr_DJ' => 'फ्रेंच (जिबौटी)',
        'fr_DZ' => 'फ्रेंच (अल्जीरिया)',
        'fr_FR' => 'फ्रेंच (फ्रान्स)',
        'fr_GA' => 'फ्रेंच (गॅबॉन)',
        'fr_GF' => 'फ्रेंच (फ्रेंच गयाना)',
        'fr_GN' => 'फ्रेंच (गिनी)',
        'fr_GP' => 'फ्रेंच (ग्वाडेलोउपे)',
        'fr_GQ' => 'फ्रेंच (इक्वेटोरियल गिनी)',
        'fr_HT' => 'फ्रेंच (हैती)',
        'fr_KM' => 'फ्रेंच (कोमोरोज)',
        'fr_LU' => 'फ्रेंच (लक्झेंबर्ग)',
        'fr_MA' => 'फ्रेंच (मोरोक्को)',
        'fr_MC' => 'फ्रेंच (मोनॅको)',
        'fr_MF' => 'फ्रेंच (सेंट मार्टिन)',
        'fr_MG' => 'फ्रेंच (मादागास्कर)',
        'fr_ML' => 'फ्रेंच (माली)',
        'fr_MQ' => 'फ्रेंच (मार्टिनिक)',
        'fr_MR' => 'फ्रेंच (मॉरिटानिया)',
        'fr_MU' => 'फ्रेंच (मॉरिशस)',
        'fr_NC' => 'फ्रेंच (न्यू कॅलेडोनिया)',
        'fr_NE' => 'फ्रेंच (नाइजर)',
        'fr_PF' => 'फ्रेंच (फ्रेंच पॉलिनेशिया)',
        'fr_PM' => 'फ्रेंच (सेंट पियरे आणि मिक्वेलोन)',
        'fr_RE' => 'फ्रेंच (रियुनियन)',
        'fr_RW' => 'फ्रेंच (रवांडा)',
        'fr_SC' => 'फ्रेंच (सेशेल्स)',
        'fr_SN' => 'फ्रेंच (सेनेगल)',
        'fr_SY' => 'फ्रेंच (सीरिया)',
        'fr_TD' => 'फ्रेंच (चाड)',
        'fr_TG' => 'फ्रेंच (टोगो)',
        'fr_TN' => 'फ्रेंच (ट्यूनिशिया)',
        'fr_VU' => 'फ्रेंच (वानुआतु)',
        'fr_WF' => 'फ्रेंच (वालिस आणि फ्यूचूना)',
        'fr_YT' => 'फ्रेंच (मायोट्टे)',
        'fy' => 'पश्चिमी फ्रिशियन',
        'fy_NL' => 'पश्चिमी फ्रिशियन (नेदरलँड)',
        'ga' => 'आयरिश',
        'ga_GB' => 'आयरिश (युनायटेड किंगडम)',
        'ga_IE' => 'आयरिश (आयर्लंड)',
        'gd' => 'स्कॉटिश गेलिक',
        'gd_GB' => 'स्कॉटिश गेलिक (युनायटेड किंगडम)',
        'gl' => 'गॅलिशियन',
        'gl_ES' => 'गॅलिशियन (स्पेन)',
        'gu' => 'गुजराती',
        'gu_IN' => 'गुजराती (भारत)',
        'gv' => 'मांक्स',
        'gv_IM' => 'मांक्स (आयल ऑफ मॅन)',
        'ha' => 'हौसा',
        'ha_GH' => 'हौसा (घाना)',
        'ha_NE' => 'हौसा (नाइजर)',
        'ha_NG' => 'हौसा (नायजेरिया)',
        'he' => 'हिब्रू',
        'he_IL' => 'हिब्रू (इस्त्राइल)',
        'hi' => 'हिंदी',
        'hi_IN' => 'हिंदी (भारत)',
        'hi_Latn' => 'हिंदी (लॅटिन)',
        'hi_Latn_IN' => 'हिंदी (लॅटिन, भारत)',
        'hr' => 'क्रोएशियन',
        'hr_BA' => 'क्रोएशियन (बोस्निया अणि हर्जेगोविना)',
        'hr_HR' => 'क्रोएशियन (क्रोएशिया)',
        'hu' => 'हंगेरियन',
        'hu_HU' => 'हंगेरियन (हंगेरी)',
        'hy' => 'आर्मेनियन',
        'hy_AM' => 'आर्मेनियन (अर्मेनिया)',
        'ia' => 'इंटरलिंग्वा',
        'ia_001' => 'इंटरलिंग्वा (विश्व)',
        'id' => 'इंडोनेशियन',
        'id_ID' => 'इंडोनेशियन (इंडोनेशिया)',
        'ig' => 'ईग्बो',
        'ig_NG' => 'ईग्बो (नायजेरिया)',
        'ii' => 'सिचुआन यी',
        'ii_CN' => 'सिचुआन यी (चीन)',
        'is' => 'आईसलँडिक',
        'is_IS' => 'आईसलँडिक (आइसलँड)',
        'it' => 'इटालियन',
        'it_CH' => 'इटालियन (स्वित्झर्लंड)',
        'it_IT' => 'इटालियन (इटली)',
        'it_SM' => 'इटालियन (सॅन मरीनो)',
        'it_VA' => 'इटालियन (व्हॅटिकन सिटी)',
        'ja' => 'जपानी',
        'ja_JP' => 'जपानी (जपान)',
        'jv' => 'जावानीज',
        'jv_ID' => 'जावानीज (इंडोनेशिया)',
        'ka' => 'जॉर्जियन',
        'ka_GE' => 'जॉर्जियन (जॉर्जिया)',
        'ki' => 'किकुयू',
        'ki_KE' => 'किकुयू (केनिया)',
        'kk' => 'कझाक',
        'kk_KZ' => 'कझाक (कझाकस्तान)',
        'kl' => 'कलाल्लिसत',
        'kl_GL' => 'कलाल्लिसत (ग्रीनलंड)',
        'km' => 'ख्मेर',
        'km_KH' => 'ख्मेर (कंबोडिया)',
        'kn' => 'कन्नड',
        'kn_IN' => 'कन्नड (भारत)',
        'ko' => 'कोरियन',
        'ko_KP' => 'कोरियन (उत्तर कोरिया)',
        'ko_KR' => 'कोरियन (दक्षिण कोरिया)',
        'ks' => 'काश्मीरी',
        'ks_Arab' => 'काश्मीरी (अरबी)',
        'ks_Arab_IN' => 'काश्मीरी (अरबी, भारत)',
        'ks_Deva' => 'काश्मीरी (देवनागरी)',
        'ks_Deva_IN' => 'काश्मीरी (देवनागरी, भारत)',
        'ks_IN' => 'काश्मीरी (भारत)',
        'ku' => 'कुर्दिश',
        'ku_TR' => 'कुर्दिश (तुर्की)',
        'kw' => 'कोर्निश',
        'kw_GB' => 'कोर्निश (युनायटेड किंगडम)',
        'ky' => 'किरगीझ',
        'ky_KG' => 'किरगीझ (किरगिझस्तान)',
        'lb' => 'लक्झेंबर्गिश',
        'lb_LU' => 'लक्झेंबर्गिश (लक्झेंबर्ग)',
        'lg' => 'गांडा',
        'lg_UG' => 'गांडा (युगांडा)',
        'ln' => 'लिंगाला',
        'ln_AO' => 'लिंगाला (अंगोला)',
        'ln_CD' => 'लिंगाला (काँगो - किंशासा)',
        'ln_CF' => 'लिंगाला (केंद्रीय अफ्रिकी प्रजासत्ताक)',
        'ln_CG' => 'लिंगाला (काँगो - ब्राझाविले)',
        'lo' => 'लाओ',
        'lo_LA' => 'लाओ (लाओस)',
        'lt' => 'लिथुआनियन',
        'lt_LT' => 'लिथुआनियन (लिथुआनिया)',
        'lu' => 'ल्यूबा-कटांगा',
        'lu_CD' => 'ल्यूबा-कटांगा (काँगो - किंशासा)',
        'lv' => 'लात्व्हियन',
        'lv_LV' => 'लात्व्हियन (लाटव्हिया)',
        'mg' => 'मलागसी',
        'mg_MG' => 'मलागसी (मादागास्कर)',
        'mi' => 'माओरी',
        'mi_NZ' => 'माओरी (न्यूझीलंड)',
        'mk' => 'मॅसेडोनियन',
        'mk_MK' => 'मॅसेडोनियन (उत्तर मॅसेडोनिया)',
        'ml' => 'मल्याळम',
        'ml_IN' => 'मल्याळम (भारत)',
        'mn' => 'मंगोलियन',
        'mn_MN' => 'मंगोलियन (मंगोलिया)',
        'mr' => 'मराठी',
        'mr_IN' => 'मराठी (भारत)',
        'ms' => 'मलय',
        'ms_BN' => 'मलय (ब्रुनेई)',
        'ms_ID' => 'मलय (इंडोनेशिया)',
        'ms_MY' => 'मलय (मलेशिया)',
        'ms_SG' => 'मलय (सिंगापूर)',
        'mt' => 'माल्टिज्',
        'mt_MT' => 'माल्टिज् (माल्टा)',
        'my' => 'बर्मी',
        'my_MM' => 'बर्मी (म्यानमार [बर्मा])',
        'nb' => 'नॉर्वेजियन बोकमाल',
        'nb_NO' => 'नॉर्वेजियन बोकमाल (नॉर्वे)',
        'nb_SJ' => 'नॉर्वेजियन बोकमाल (स्वालबर्ड आणि जान मायेन)',
        'nd' => 'उत्तर देबेली',
        'nd_ZW' => 'उत्तर देबेली (झिम्बाब्वे)',
        'ne' => 'नेपाळी',
        'ne_IN' => 'नेपाळी (भारत)',
        'ne_NP' => 'नेपाळी (नेपाळ)',
        'nl' => 'डच',
        'nl_AW' => 'डच (अरुबा)',
        'nl_BE' => 'डच (बेल्जियम)',
        'nl_BQ' => 'डच (कॅरिबियन नेदरलँड्स)',
        'nl_CW' => 'डच (क्युरासाओ)',
        'nl_NL' => 'डच (नेदरलँड)',
        'nl_SR' => 'डच (सुरिनाम)',
        'nl_SX' => 'डच (सिंट मार्टेन)',
        'nn' => 'नॉर्वेजियन न्योर्स्क',
        'nn_NO' => 'नॉर्वेजियन न्योर्स्क (नॉर्वे)',
        'no' => 'नोर्वेजियन',
        'no_NO' => 'नोर्वेजियन (नॉर्वे)',
        'om' => 'ओरोमो',
        'om_ET' => 'ओरोमो (इथिओपिया)',
        'om_KE' => 'ओरोमो (केनिया)',
        'or' => 'उडिया',
        'or_IN' => 'उडिया (भारत)',
        'os' => 'ओस्सेटिक',
        'os_GE' => 'ओस्सेटिक (जॉर्जिया)',
        'os_RU' => 'ओस्सेटिक (रशिया)',
        'pa' => 'पंजाबी',
        'pa_Arab' => 'पंजाबी (अरबी)',
        'pa_Arab_PK' => 'पंजाबी (अरबी, पाकिस्तान)',
        'pa_Guru' => 'पंजाबी (गुरुमुखी)',
        'pa_Guru_IN' => 'पंजाबी (गुरुमुखी, भारत)',
        'pa_IN' => 'पंजाबी (भारत)',
        'pa_PK' => 'पंजाबी (पाकिस्तान)',
        'pl' => 'पोलिश',
        'pl_PL' => 'पोलिश (पोलंड)',
        'ps' => 'पश्तो',
        'ps_AF' => 'पश्तो (अफगाणिस्तान)',
        'ps_PK' => 'पश्तो (पाकिस्तान)',
        'pt' => 'पोर्तुगीज',
        'pt_AO' => 'पोर्तुगीज (अंगोला)',
        'pt_BR' => 'पोर्तुगीज (ब्राझिल)',
        'pt_CH' => 'पोर्तुगीज (स्वित्झर्लंड)',
        'pt_CV' => 'पोर्तुगीज (केप व्हर्डे)',
        'pt_GQ' => 'पोर्तुगीज (इक्वेटोरियल गिनी)',
        'pt_GW' => 'पोर्तुगीज (गिनी-बिसाउ)',
        'pt_LU' => 'पोर्तुगीज (लक्झेंबर्ग)',
        'pt_MO' => 'पोर्तुगीज (मकाओ एसएआर चीन)',
        'pt_MZ' => 'पोर्तुगीज (मोझाम्बिक)',
        'pt_PT' => 'पोर्तुगीज (पोर्तुगाल)',
        'pt_ST' => 'पोर्तुगीज (साओ टोम आणि प्रिंसिपे)',
        'pt_TL' => 'पोर्तुगीज (तिमोर-लेस्ते)',
        'qu' => 'क्वेचुआ',
        'qu_BO' => 'क्वेचुआ (बोलिव्हिया)',
        'qu_EC' => 'क्वेचुआ (इक्वाडोर)',
        'qu_PE' => 'क्वेचुआ (पेरू)',
        'rm' => 'रोमान्श',
        'rm_CH' => 'रोमान्श (स्वित्झर्लंड)',
        'rn' => 'रुन्दी',
        'rn_BI' => 'रुन्दी (बुरुंडी)',
        'ro' => 'रोमानियन',
        'ro_MD' => 'रोमानियन (मोल्डोव्हा)',
        'ro_RO' => 'रोमानियन (रोमानिया)',
        'ru' => 'रशियन',
        'ru_BY' => 'रशियन (बेलारूस)',
        'ru_KG' => 'रशियन (किरगिझस्तान)',
        'ru_KZ' => 'रशियन (कझाकस्तान)',
        'ru_MD' => 'रशियन (मोल्डोव्हा)',
        'ru_RU' => 'रशियन (रशिया)',
        'ru_UA' => 'रशियन (युक्रेन)',
        'rw' => 'किन्यार्वान्डा',
        'rw_RW' => 'किन्यार्वान्डा (रवांडा)',
        'sa' => 'संस्कृत',
        'sa_IN' => 'संस्कृत (भारत)',
        'sc' => 'सर्दिनियन',
        'sc_IT' => 'सर्दिनियन (इटली)',
        'sd' => 'सिंधी',
        'sd_Arab' => 'सिंधी (अरबी)',
        'sd_Arab_PK' => 'सिंधी (अरबी, पाकिस्तान)',
        'sd_Deva' => 'सिंधी (देवनागरी)',
        'sd_Deva_IN' => 'सिंधी (देवनागरी, भारत)',
        'sd_IN' => 'सिंधी (भारत)',
        'sd_PK' => 'सिंधी (पाकिस्तान)',
        'se' => 'उत्तरी सामी',
        'se_FI' => 'उत्तरी सामी (फिनलंड)',
        'se_NO' => 'उत्तरी सामी (नॉर्वे)',
        'se_SE' => 'उत्तरी सामी (स्वीडन)',
        'sg' => 'सांगो',
        'sg_CF' => 'सांगो (केंद्रीय अफ्रिकी प्रजासत्ताक)',
        'sh' => 'सर्बो-क्रोएशियन',
        'sh_BA' => 'सर्बो-क्रोएशियन (बोस्निया अणि हर्जेगोविना)',
        'si' => 'सिंहला',
        'si_LK' => 'सिंहला (श्रीलंका)',
        'sk' => 'स्लोव्हाक',
        'sk_SK' => 'स्लोव्हाक (स्लोव्हाकिया)',
        'sl' => 'स्लोव्हेनियन',
        'sl_SI' => 'स्लोव्हेनियन (स्लोव्हेनिया)',
        'sn' => 'शोना',
        'sn_ZW' => 'शोना (झिम्बाब्वे)',
        'so' => 'सोमाली',
        'so_DJ' => 'सोमाली (जिबौटी)',
        'so_ET' => 'सोमाली (इथिओपिया)',
        'so_KE' => 'सोमाली (केनिया)',
        'so_SO' => 'सोमाली (सोमालिया)',
        'sq' => 'अल्बानियन',
        'sq_AL' => 'अल्बानियन (अल्बानिया)',
        'sq_MK' => 'अल्बानियन (उत्तर मॅसेडोनिया)',
        'sr' => 'सर्बियन',
        'sr_BA' => 'सर्बियन (बोस्निया अणि हर्जेगोविना)',
        'sr_Cyrl' => 'सर्बियन (सीरिलिक)',
        'sr_Cyrl_BA' => 'सर्बियन (सीरिलिक, बोस्निया अणि हर्जेगोविना)',
        'sr_Cyrl_ME' => 'सर्बियन (सीरिलिक, मोंटेनेग्रो)',
        'sr_Cyrl_RS' => 'सर्बियन (सीरिलिक, सर्बिया)',
        'sr_Latn' => 'सर्बियन (लॅटिन)',
        'sr_Latn_BA' => 'सर्बियन (लॅटिन, बोस्निया अणि हर्जेगोविना)',
        'sr_Latn_ME' => 'सर्बियन (लॅटिन, मोंटेनेग्रो)',
        'sr_Latn_RS' => 'सर्बियन (लॅटिन, सर्बिया)',
        'sr_ME' => 'सर्बियन (मोंटेनेग्रो)',
        'sr_RS' => 'सर्बियन (सर्बिया)',
        'su' => 'सुंदानीज',
        'su_ID' => 'सुंदानीज (इंडोनेशिया)',
        'su_Latn' => 'सुंदानीज (लॅटिन)',
        'su_Latn_ID' => 'सुंदानीज (लॅटिन, इंडोनेशिया)',
        'sv' => 'स्वीडिश',
        'sv_AX' => 'स्वीडिश (अ‍ॅलँड बेटे)',
        'sv_FI' => 'स्वीडिश (फिनलंड)',
        'sv_SE' => 'स्वीडिश (स्वीडन)',
        'sw' => 'स्वाहिली',
        'sw_CD' => 'स्वाहिली (काँगो - किंशासा)',
        'sw_KE' => 'स्वाहिली (केनिया)',
        'sw_TZ' => 'स्वाहिली (टांझानिया)',
        'sw_UG' => 'स्वाहिली (युगांडा)',
        'ta' => 'तामिळ',
        'ta_IN' => 'तामिळ (भारत)',
        'ta_LK' => 'तामिळ (श्रीलंका)',
        'ta_MY' => 'तामिळ (मलेशिया)',
        'ta_SG' => 'तामिळ (सिंगापूर)',
        'te' => 'तेलगू',
        'te_IN' => 'तेलगू (भारत)',
        'tg' => 'ताजिक',
        'tg_TJ' => 'ताजिक (ताजिकिस्तान)',
        'th' => 'थाई',
        'th_TH' => 'थाई (थायलंड)',
        'ti' => 'तिग्रिन्या',
        'ti_ER' => 'तिग्रिन्या (एरिट्रिया)',
        'ti_ET' => 'तिग्रिन्या (इथिओपिया)',
        'tk' => 'तुर्कमेन',
        'tk_TM' => 'तुर्कमेन (तुर्कमेनिस्तान)',
        'tl' => 'टागालोग',
        'tl_PH' => 'टागालोग (फिलिपिन्स)',
        'to' => 'टोंगन',
        'to_TO' => 'टोंगन (टोंगा)',
        'tr' => 'तुर्की',
        'tr_CY' => 'तुर्की (सायप्रस)',
        'tr_TR' => 'तुर्की (तुर्की)',
        'tt' => 'तातर',
        'tt_RU' => 'तातर (रशिया)',
        'ug' => 'उइगुर',
        'ug_CN' => 'उइगुर (चीन)',
        'uk' => 'युक्रेनियन',
        'uk_UA' => 'युक्रेनियन (युक्रेन)',
        'ur' => 'उर्दू',
        'ur_IN' => 'उर्दू (भारत)',
        'ur_PK' => 'उर्दू (पाकिस्तान)',
        'uz' => 'उझ्बेक',
        'uz_AF' => 'उझ्बेक (अफगाणिस्तान)',
        'uz_Arab' => 'उझ्बेक (अरबी)',
        'uz_Arab_AF' => 'उझ्बेक (अरबी, अफगाणिस्तान)',
        'uz_Cyrl' => 'उझ्बेक (सीरिलिक)',
        'uz_Cyrl_UZ' => 'उझ्बेक (सीरिलिक, उझबेकिस्तान)',
        'uz_Latn' => 'उझ्बेक (लॅटिन)',
        'uz_Latn_UZ' => 'उझ्बेक (लॅटिन, उझबेकिस्तान)',
        'uz_UZ' => 'उझ्बेक (उझबेकिस्तान)',
        'vi' => 'व्हिएतनामी',
        'vi_VN' => 'व्हिएतनामी (व्हिएतनाम)',
        'wo' => 'वोलोफ',
        'wo_SN' => 'वोलोफ (सेनेगल)',
        'xh' => 'खोसा',
        'xh_ZA' => 'खोसा (दक्षिण आफ्रिका)',
        'yi' => 'यिद्दिश',
        'yi_001' => 'यिद्दिश (विश्व)',
        'yo' => 'योरुबा',
        'yo_BJ' => 'योरुबा (बेनिन)',
        'yo_NG' => 'योरुबा (नायजेरिया)',
        'zh' => 'चीनी',
        'zh_CN' => 'चीनी (चीन)',
        'zh_HK' => 'चीनी (हाँगकाँग एसएआर चीन)',
        'zh_Hans' => 'चीनी (सरलीकृत)',
        'zh_Hans_CN' => 'चीनी (सरलीकृत, चीन)',
        'zh_Hans_HK' => 'चीनी (सरलीकृत, हाँगकाँग एसएआर चीन)',
        'zh_Hans_MO' => 'चीनी (सरलीकृत, मकाओ एसएआर चीन)',
        'zh_Hans_SG' => 'चीनी (सरलीकृत, सिंगापूर)',
        'zh_Hant' => 'चीनी (पारंपारिक)',
        'zh_Hant_HK' => 'चीनी (पारंपारिक, हाँगकाँग एसएआर चीन)',
        'zh_Hant_MO' => 'चीनी (पारंपारिक, मकाओ एसएआर चीन)',
        'zh_Hant_TW' => 'चीनी (पारंपारिक, तैवान)',
        'zh_MO' => 'चीनी (मकाओ एसएआर चीन)',
        'zh_SG' => 'चीनी (सिंगापूर)',
        'zh_TW' => 'चीनी (तैवान)',
        'zu' => 'झुलू',
        'zu_ZA' => 'झुलू (दक्षिण आफ्रिका)',
    ],
];
